@@ -40,7 +40,7 @@ my $result;
 
 if (($ld = new Net::LDAPapi($ldap_server)) == -1)
 {
-    die "Connection Failed!";
+    die "Unable to initialize!";
 }
 
 #ldap_set_option(0,LDAP_OPT_DEBUG_LEVEL,-1);
@@ -53,8 +53,9 @@ if (($ld = new Net::LDAPapi($ldap_server)) == -1)
 #if ($ld->bind_s("tester","tester",LDAP_AUTH_SASL) != LDAP_SUCCESS)
 if ($ld->bind_s != LDAP_SUCCESS)
 {
+    my $errstr=$ld->errstring;
     $ld->unbind;
-    die "bind: ", $ld->errstring, ": ", $ld->extramsg;
+    die "bind: ", $errstr;
 }
 
 #  This will set the size limit to $sizelimit from above.  The command
@@ -114,7 +115,7 @@ while (1)
 
         #
         #  Cycle Through Each Attribute
-        for ($attr = $ld->first_attribute; $attr ne ""; $attr = $ld->next_attribute)
+        for ($attr = $ld->first_attribute; defined($attr); $attr = $ld->next_attribute)
         {
 
             #
@@ -129,7 +130,7 @@ while (1)
     $ld->msgfree;
 
 }
-if ( $result == undef && $ld->err != LDAP_SUCCESS)
+if ( !defined($result) && $ld->err != LDAP_SUCCESS)
 {
     $ld->unbind;
     die "result: ", $ld->errstring, ": ", $ld->extramsg;
@@ -164,6 +165,7 @@ foreach $dn (keys %record)
             }
         }
     }
+    print "\n";
 }
 
 exit;
